@@ -26,7 +26,7 @@ from hspylib.core.tools.text_tools import camelcase, ensure_endswith
 from hspylib.modules.application.application import Application
 from hspylib.modules.application.exit_status import ExitStatus
 from hspylib.modules.application.version import Version
-from hspylib.modules.cli.vt100.terminal import Terminal
+from hspylib.modules.cli.terminal import Terminal
 from hspylib.modules.fetch.fetch import get
 from textwrap import dedent
 from typing import List
