@@ -19,7 +19,7 @@ from hspylib.core.tools.commons import human_readable_bytes, sysout
 from hspylib.modules.application.exit_status import ExitStatus
 from hspylib.modules.application.version import Version
 from hspylib.modules.cli.keyboard import Keyboard
-from hspylib.modules.cli.vt100.terminal import Terminal
+from hspylib.modules.cli.terminal import Terminal
 from textwrap import dedent
 from time import sleep
 from typing import List
