@@ -21,7 +21,7 @@ from hspylib.core.zoned_datetime import now
 from hspylib.modules.application.argparse.argument_parser import HSArgumentParser
 from hspylib.modules.application.exit_status import ExitStatus
 from hspylib.modules.application.version import Version
-from hspylib.modules.cli.vt100.terminal import Terminal
+from hspylib.modules.cli.terminal import Terminal
 from textwrap import dedent
 from typing import List
 
